@@ -3,13 +3,9 @@ use strictures;
 use Gtk3;
 use RogersMine::App;
 
-BEGIN {
-  our $VERSION = 0.1.5;
-}
-
 sub main {
   my $window = Gtk3::Window->new('toplevel');
-  $window->signal_connect(delete_event => \&Gtk3::main_quit);
+  $window->set_title("Rogers Mine");
   my $vbox = Gtk3::VBox->new;
   my $rl = Gtk3::Label->new('Rows');
   my $rows = Gtk3::Entry->new;
@@ -35,11 +31,12 @@ sub main {
   $start->signal_connect(clicked => sub { start_game($rows->get_text, $cols->get_text, $lives->get_text, $risk->get_text, @_); });
   $vbox->add($start);
   $window->add($vbox);
+  $window->signal_connect(delete_event => \&Gtk3::main_quit);
   $window->show_all;
 }
 
 sub start_game {
-  my ($rows, $cols, $lives, $risk, $start) = @_;
+  my ($rows, $cols, $lives, $risk, $btn, $evt) = @_;
   my $app = RogersMine::App->new(rows => $rows, cols => $cols, lives => $lives, risk => $risk);
   $app->window->show_all;
 }
