@@ -6,6 +6,7 @@ use Gtk3;
 use RogersMine::MineField;
 use namespace::autoclean;
 
+has complete => (is => 'rw', default => sub { 0; });
 has rows => (is => 'ro');
 has cols => (is => 'ro');
 has lives => (is => 'ro');
@@ -23,7 +24,7 @@ has window => (is => 'lazy');
 
 sub _build_info {
   my $self = shift;
-  Gtk3::Label->new($self->minefield->lives);
+  Gtk3::Label->new($self->lives);
 }
 
 sub _build_window {
@@ -48,21 +49,22 @@ sub _build_window {
 
 sub click_btn {
   my ($self, $i, $j, $btn, $evt) = @_;
+  return if $self->complete;
   my $safe = $self->minefield->click($i, $j);
-  if($self->minefield->complete) {
-    if($self->minefield->lives > 0) {
-      $self->info->set_text("You won with @{[$self->minefield->lives]} remaining");
-    } else {
-      $self->info->set_text("You Lost");
-    }
-    return;
-  }
   if($safe) {
     $btn->set_label($safe);
   } else {
     $self->info->set_text($self->minefield->lives);
     $btn->set_label('*');
   }
+  if($self->minefield->complete) {
+    $self->complete(1);
+    if($self->minefield->lives > 0) {
+      $self->info->set_text("You won with @{[$self->minefield->lives]} remaining");
+    } else {
+      $self->info->set_text("You Lost");
+    }
+  }
 }
 
 1;
